django-soapbox |version|
========================

This application provides a simple mechanism for creating and
displaying messages -- such as announcemnts or site information -- on
a `Django <https://www.djangoproject.com/>`_-powered site. Messages can
be turned on or off, and can be set to display globally or only on a
subset of a site's URLs.


Documentation contents
----------------------

.. toctree::
   :maxdepth: 1

   install
   overview



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

